@@ -38,14 +38,13 @@
 # include <gsasl.h>
 #else
 # include "base64.h"
-# include "hmac.h"
+# include "md5-apps.h"
 #endif
 
-#include "c-ctype.h"
 #include "gettext.h"
-#include "xalloc.h"
-#include "xvasprintf.h"
+#define _(string) gettext(string)
 
+#include "xalloc.h"
 #include "list.h"
 #include "readbuf.h"
 #include "net.h"
@@ -448,7 +447,7 @@ int smtp_init(smtp_server_t *srv, const char *ehlo_domain, list_t **errmsg,
         /* make line uppercase */
         for (i = 4; (size_t)i < len; i++)
         {
-            s[i] = c_toupper((unsigned char)s[i]);
+            s[i] = toupper((unsigned char)s[i]);
         }
         /* search capabilities */
         if (strncmp(s + 4, "STARTTLS", 8) == 0)
@@ -807,7 +806,7 @@ int smtp_auth_cram_md5(smtp_server_t *srv, const char *user,
         return SMTP_EPROTO;
     }
     list_xfree(msg, free);
-    hmac_md5(password, strlen(password), b64, len, digest);
+    md5_hmac(password, strlen(password), b64, len, digest);
     free(b64);
 
     /* construct username + ' ' + digest_in_hex */
@@ -982,11 +981,7 @@ int smtp_auth(smtp_server_t *srv,
         const char *hostname,
         const char *user,
         const char *password,
-#ifdef HAVE_LIBGSASL
         const char *ntlmdomain,
-#else
-        const char *ntlmdomain UNUSED,
-#endif
         const char *auth_mech,
         char *(*password_callback)(const char *hostname, const char *user),
         list_t **error_msg,
@@ -1281,6 +1276,8 @@ int smtp_auth(smtp_server_t *srv,
 
 #else /* not HAVE_LIBGSASL */
 
+    (void)ntlmdomain;
+
     char *callback_password = NULL;
     int e;
 
@@ -1893,5 +1890,5 @@ void smtp_close(smtp_server_t *srv)
         tls_close(&srv->tls);
     }
 #endif /* HAVE_TLS */
-    close(srv->fd);
+    net_close_socket(srv->fd);
 }
